ScrollbarMode

Enum ScrollbarMode 

pub enum ScrollbarMode {
    Off,
    On,
    Auto,
    Active,
}
When the scrollbar thumb is visible.

Variants



Off

Never draw the scrollbar.



On

Always draw the scrollbar.



Auto

Draw the scrollbar only when content overflows the viewport.



Active

Draw the scrollbar only while a gesture or animation is active.